referrerpolicy=no-referrer-when-downgrade

add_external_asset

Function add_external_asset 

pub fn add_external_asset<T: Config>(
    internal_asset: T::AssetId,
    external_asset: T::AssetId,
)
Approve an external asset for a given internal asset.

Snapshots the external asset’s live decimals at registration time and increments PsmInfo::external_count.

Dispatch Origin

Must match the PSM instance’s full_admin (the Full privilege level).

Parameters

  • internal_asset: The PSM instance to approve the external on.
  • external_asset: The external asset to approve.

Errors

Events

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::add_external_asset.