referrerpolicy=no-referrer-when-downgrade

remove_psm

Function remove_psm 

pub fn remove_psm<T: Config>(internal_asset: T::AssetId)
Remove a PSM. Callable by the current full_admin. All approved externals must be removed first and aggregate PSM debt must be zero.

If a creation deposit was taken, it is always returned to the account that originally paid it, regardless of any later admin reassignment.

Dispatch Origin

Must match the PSM’s full_admin.

Parameters

  • internal_asset: The PSM instance to remove.

Errors

Events

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::remove_psm.