referrerpolicy=no-referrer-when-downgrade

set_max_psm_debt

Function set_max_psm_debt 

pub fn set_max_psm_debt<T: Config>(ratio: Permill)
Set the maximum PSM debt as a percentage of total maximum issuance.

Dispatch Origin

Must be Config::ManagerOrigin.

Events

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::set_max_psm_debt.