referrerpolicy=no-referrer-when-downgrade

set_redemption_fee

Function set_redemption_fee 

pub fn set_redemption_fee<T: Config>(asset_id: T::AssetId, fee: Permill)
Set the redemption fee for a specific asset (internal → external).

Dispatch Origin

Must be Config::ManagerOrigin.

Parameters

  • asset_id: The external stablecoin to configure
  • fee: The new redemption fee as a Permill

Events

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::set_redemption_fee.