pub fn add_external_asset<T: Config>(asset_id: T::AssetId)Expand description
Add an external stablecoin to the approved list.
Dispatch Origin
Must be Config::ManagerOrigin.
Parameters
asset_id: The external stablecoin to add
Errors
Error::AssetAlreadyApproved: If the asset is already in the approved list
Events
Event::ExternalAssetAdded: Emitted on successful addition
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::add_external_asset.