pub fn set_asset_ceiling_weight<T: Config>(
asset_id: T::AssetId,
weight: Permill,
)Expand description
Set the per-asset debt ceiling weight.
Dispatch Origin
Must be Config::ManagerOrigin.
Details
Ratios act as weights normalized against the sum of all asset weights:
max_asset_debt = (ratio / sum_of_all_ratios) * MaxPsmDebtOfTotal * MaximumIssuance
With a single asset, the weight always normalizes to 100% of the PSM ceiling.
Parameters
asset_id: The external stablecoin to configureratio: Weight for this asset’s share of the total PSM ceiling
Events
Event::AssetCeilingWeightUpdated: Emitted with old and new values
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::set_asset_ceiling_weight.