referrerpolicy=no-referrer-when-downgrade

set_asset_status

Function set_asset_status 

pub fn set_asset_status<T: Config>(
    asset_id: T::AssetId,
    status: CircuitBreakerLevel,
)
Set the circuit breaker status for a specific external asset.

Dispatch Origin

Must be Config::ManagerOrigin.

Details

Controls which operations are allowed for this asset:

Parameters

  • asset_id: The external stablecoin to configure
  • status: The new circuit breaker level for this asset

Errors

Events

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::set_asset_status.