pub fn set_minting_fee<T: Config>(
internal_asset: T::AssetId,
external_asset: T::AssetId,
fee: Permill,
)Expand description
Set the minting fee for an (internal_asset, external_asset) pair.
Dispatch Origin
Must match the PSM instance’s full_admin (the Full privilege level).
Parameters
internal_asset: The PSM instance to configure.external_asset: The external asset whose minting fee is being updated.fee: The new minting fee.
Errors
Error::InsufficientPrivilege: If the origin only hasEmergencyprivileges.Error::AssetNotApproved: Ifexternal_assetis not approved oninternal_asset.
Events
Event::MintingFeeUpdated: Emitted with old and new values.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::set_minting_fee.