referrerpolicy=no-referrer-when-downgrade

set_minting_fee

Function set_minting_fee 

pub fn set_minting_fee<T: Config>(asset_id: T::AssetId, fee: Permill)
Set the minting fee for a specific asset (external → internal).

Dispatch Origin

Must be Config::ManagerOrigin.

Parameters

  • asset_id: The external stablecoin to configure
  • fee: The new minting fee as a Permill

Events

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::set_minting_fee.